#!/usr/bin/env python

# Simple password generator that uses the dictionary file located at ./words to create 
# multi-word passphrases.  First user argument is the number of passphrases to generate
# and second argument is the number of words in each passphrase.  Set the -g flag to 
# generate a single line of output suitable for passing to gpg (no trailing newline)

import random
import linecache
import sys
import argparse

parser = argparse.ArgumentParser()

parser.add_argument("-d", "--dictionary",
default="./words",
help="Path to dictionary file.  Defaults to ./words",
action="store")

parser.add_argument("-w", "--words",
help="Number of words in passphrase",
action="store")

parser.add_argument("-p", "--passphrases",
help="Number of passphrases to generate",
action="store")

parser.add_argument("-g", "--gpgmode", 
help="Run in gpg mode.  Prints a single, 10-word passphrase without a trailing newline.  Ignores -w and -p arguments",
action="store_true")

args = parser.parse_args()
if args.gpgmode:
	output = ""
	for word in range(0, 10):
		with open(args.dictionary) as wordlist:
			output = output + (linecache.getline(args.dictionary, (random.SystemRandom().randint(1,len(wordlist.readlines()))))).rstrip()
	sys.stdout.write(output)

else:
	for iteration in range (0, int(args.passphrases)):
		output = ""
		for word in range(0, int(args.words)):
			with open(args.dictionary) as wordlist:
				output = output + (linecache.getline(args.dictionary, (random.SystemRandom().randint(1,len(wordlist.readlines()))))).rstrip()
		print (output)
